Struct amazon_sp_vendor_direct_fulfillment_orders::models::acknowledgement_status::AcknowledgementStatus
source · [−]Expand description
AcknowledgementStatus : Status of acknowledgement.
Fields
code: Option<String>Acknowledgement code is a unique two digit value which indicates the status of the acknowledgement. For a list of acknowledgement codes that Amazon supports, see the Vendor Direct Fulfillment APIs Use Case Guide.
description: Option<String>Reason for the acknowledgement code.
Implementations
sourceimpl AcknowledgementStatus
impl AcknowledgementStatus
sourcepub fn new() -> AcknowledgementStatus
pub fn new() -> AcknowledgementStatus
Status of acknowledgement.